clear all;
%% This code is used to automatically find nucleoids labeled by fluorescently tagged HU
%% and follow in time to quantify intensity to evaluate photobleaching rate
%% Reference: Wu et al(2015) Front. Microbiol. 6:607. doi: 10.3389/fmicb.2015.00607
%% For this code, you need to initiate the dipimage plugin, which can be downloaded from http://www.diplib.org. 
% note that here, we only used the function gaussf for gaussian blurring
% from the dipimage library. The readers may find alternative gaussian blur
% functions provided by Matlab. 
%% open images from the folder (to be filled in between '').
cd('');
figname=dir('*.tif');
allint=[];
ST=[];
fr=length(figname);

I=double(imread(figname(1).name));

%% Background subtraction
bg=gaussf(I,8,'best'); % gaussian blur for background subtraction
bg=double(bg);
I=double(I);
J=I-bg; % subtract background
K=J>200; % The 200 here was set manually for TagBFP
%% Find objects
Ibi=bwmorph(K,'clean'); 
Ibi=bwareaopen(Ibi,150); % produce binary image and get rid of noise
imwrite(uint8(Ibi),'TagBFPbi.tif','tiff'); % write binary image for quality control later
[L,num]=bwlabel(Ibi,4);
int=[];
 for k=1:fr;
     M=imread(figname(k).name);
     [n,xout]=hist(M(:),100);
     [nn,xx]=max(n);
     bgval=xout(xx);% find background value 
     M=M-bg;
     int1=[];
            for i=1:num;
                Ilab=M(L==i);
                int2m=mean(Ilab);
                int1=cat(2,int1,int2m);
            end
     
     int=cat(1,int,int1);
 end
%% save the variables into datafiles
inttagbfp=int;
cd('');% open folder to store the data
save('tagbfp.mat','inttagbfp');
%% After all the strains were measured, import all the data and plot as follows
plot((0:1:size(inttagbfp,1))',inttagbfp,'Color','k');
hold on;plot((0:1:size(intsbfp,1))',intsbfp,'Color','m');
