clear all;
%% This code is used to automatically find ori spots labeled by fluorescently tagged lacI
%% and follow in time to quantify intensity to evaluate photobleaching rate
%% Reference: Wu et al(2015) Front. Microbiol. 6:607. doi: 10.3389/fmicb.2015.00607
%% initiate the dipimage plugin, which can be downloaded from http://www.diplib.org. 
% note that here, we only used the function gaussf for gaussian blurring
% from the dipimage library. The readers may find alternative gaussian blur
% functions provided by Matlab. 
%% open images from the folder (to be filled in between '').
cd(''); 
files=dir('*.tif');
sumpix=[]; % total number of all pixels in found oris at each time point
sumint=[]; % total intensity value in found oris at each time point
sumspots=[]; % total number of ori spots found at each time point 
spotsdats=[]; % intensity value of each single spots at each time point

for i=1:length(files);
f1=double(imread(files(i).name));
[n,xout]=hist(f1(:),100);
[nn,xx]=max(n);
bgval=xout(xx);
bg=gaussf(f1,8,'best');
bg=double(bg);
f1b=f1-bg;
f1c=f1b>30;
f1d=bwmorph(f1c,'clean');
f1e=bwareaopen(f1d,8);
f1f=f1e-bwareaopen(f1e,150);
f1g=f1f.*(f1-bgval);
[ys,xs]=find(f1f==1);
pix=numel(ys);
sumpix=cat(1,sumpix,pix);
[Lab,nspots]=bwlabel(f1f,8);
sumspots=cat(1,sumspots,nspots);   
sumint=cat(1,sumint,sum(f1g(:)));
if i==1;
    inispots=nspots;
end
spotsdat=zeros(1,inispots);
if nspots>=1;
    for j=1:min(nspots,inispots);
        f1h=(Lab==j);
        f1i=f1g.*double(f1h);
        spotsdat(1,j)=sum(f1i(:));
    end
end
% add zeros if not all spots were found;
spotsdats=cat(1,spotsdats,spotsdat);
if mod(i,50)==0;i %% output the frame number every 50 frames.
end
end
spotssort=sort(spotsdats,2); % at each time point, the intensity values of spots were sorted from high to low

